/**
 * COPYRIGHT 2019 Flirc, Inc. All rights reserved.
 *
 * This copyright notice is Copyright Management Information under 17 USC 1202
 * and is included to protect this work and deter copyright infringement.
 * Removal or alteration of this Copyright Management Information without
 * the express written permission of Flirc, Inc. is prohibited, and any
 * such unauthorized removal or alteration will be a violation of federal law.
 *
 * @file
 * @brief   temporary file, will be replaced
 */

#ifndef I__PVK_H
#define I__PVK_H

#include <stdint.h>

#ifdef __cplusplus
extern "C" {
#endif

/* opaque data pointer */
struct dev_t;

/* libusb private data */
struct libusb_priv {
	uint16_t VID;
	uint16_t PID;
	uint8_t interface;
	uint8_t port;
	char mfr[45];
	uint8_t debug;
};

struct libhid_priv {
	uint16_t VID;
	uint16_t PID;
	int iface;
};

#define LIBUSB_DEV	0
#define SERIAL_DEV	1
#define HID_DEV		2

/**
 * dev_open() opens a device
 *
 * @param type - device type to open, SERIAL, HID, LIBUSB (above)
 * @param priv - private pointer to transport specific data
 *
 * @return      None.
 */
struct dev_t *dev_open(uint8_t type, void *priv);

/**
 * dev_close() closes an open device
 *
 * @param dev   - pointer to device
 *
 * @return      None.
 */
int dev_close(struct dev_t *dev);

/**
 * dev_send_cmd() abstracted command layer
 *
 * @param dev   - pointer to device
 * @param *cmd  - string command
 * @param *data - pointer to buffer to write
 * @param len 	- length of buffer
 *
 * @return      int	- 0 Success, < 0 Error
 */
int dev_send_cmd(struct dev_t *dev, const char *cmd,
		uint8_t *data, uint32_t len);

/**
 * dev_send_cmd() abstracted data layer. Raw data packet type that
 * can be used on the device for better transfer throughput.
 *
 * @param dev   - pointer to device
 * @param *data - pointer to buffer to write
 * @param len 	- length of buffer
 *
 * @return      int	- 0 Success, < 0 Error
 */
int dev_send_data(struct dev_t *dev, uint8_t *data, uint32_t len);

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* I__PKV_H__ */
